@@ -4,7 +4,7 @@ import time
 
 from .baseclient import BaseClient
 from .payloads import Payload
-from .utils import remove_none
+from .utils import remove_none, get_event_loop
 
 
 class Presence(BaseClient):
@@ -13,20 +13,22 @@ class Presence(BaseClient):
         super().__init__(*args, **kwargs)
 
     def update(self, pid: int = os.getpid(),
-                     state: str = None, details: str = None,
-                     start: int = None, end: int = None,
-                     large_image: str = None, large_text: str = None,
-                     small_image: str = None, small_text: str = None,
-                     party_id: str = None, party_size: list = None,
-                     join: str = None, spectate: str = None,
-                     match: str = None, buttons: list = None,
-                     instance: bool = True,
-                     _donotuse=True):
+               state: str = None, details: str = None,
+               start: int = None, end: int = None,
+               large_image: str = None, large_text: str = None,
+               small_image: str = None, small_text: str = None,
+               party_id: str = None, party_size: list = None,
+               join: str = None, spectate: str = None,
+               match: str = None, buttons: list = None,
+               instance: bool = True,
+               _donotuse=True):
 
         if _donotuse is True:
-            payload = Payload.set_activity(pid=pid, state=state, details=details, start=start, end=end, large_image=large_image, large_text=large_text,
-                                       small_image=small_image, small_text=small_text, party_id=party_id, party_size=party_size, join=join, spectate=spectate,
-                                       match=match, buttons=buttons, instance=instance, activity=True)
+            payload = Payload.set_activity(pid=pid, state=state, details=details, start=start, end=end,
+                                           large_image=large_image, large_text=large_text,
+                                           small_image=small_image, small_text=small_text, party_id=party_id,
+                                           party_size=party_size, join=join, spectate=spectate,
+                                           match=match, buttons=buttons, instance=instance, activity=True)
 
         else:
             payload = _donotuse
@@ -39,7 +41,7 @@ class Presence(BaseClient):
         return self.loop.run_until_complete(self.read_output())
 
     def connect(self):
-        self.update_event_loop(self.get_event_loop())
+        self.update_event_loop(get_event_loop())
         self.loop.run_until_complete(self.handshake())
 
     def close(self):
@@ -62,10 +64,11 @@ class AioPresence(BaseClient):
                      join: str = None, spectate: str = None,
                      match: str = None, buttons: list = None,
                      instance: bool = True):
-
-        payload = Payload.set_activity(pid=pid, state=state, details=details, start=start, end=end, large_image=large_image, large_text=large_text,
-                                    small_image=small_image, small_text=small_text, party_id=party_id, party_size=party_size, join=join, spectate=spectate,
-                                    match=match, buttons=buttons, instance=instance, activity=True)
+        payload = Payload.set_activity(pid=pid, state=state, details=details, start=start, end=end,
+                                       large_image=large_image, large_text=large_text,
+                                       small_image=small_image, small_text=small_text, party_id=party_id,
+                                       party_size=party_size, join=join, spectate=spectate,
+                                       match=match, buttons=buttons, instance=instance, activity=True)
         self.send_data(1, payload)
         return await self.read_output()
 
@@ -75,7 +78,7 @@ class AioPresence(BaseClient):
         return await self.read_output()
 
     async def connect(self):
-        self.update_event_loop(self.get_event_loop())
+        self.update_event_loop(get_event_loop())
         await self.handshake()
 
     def close(self):
